@@ -253,8 +253,11 @@ class Camera(BaseCamera):
                     # ---------- before anything - we decode the web command EXECUTE EXECUTION
                     expression,value = mmread_n_clear( )
                     #print(f"i... expression == {expression}  value == {value}")
-                    globals()[expression] = eval(value)
-                    # print(".... substract_background", substract_background, not(substract_background) )
+                    try:
+                        globals()[expression] = eval(value)
+                    except:
+                        print("X... EXEC FAIL",expression,value)
+                        # print(".... substract_background", substract_background, not(substract_background) )
                     # globals()["substract_background"] = value
 
                     if save_background:
@@ -353,6 +356,8 @@ class Camera(BaseCamera):
                         senh.setbox(f"x {speedx:.3f}",  senh.speedx)
                     if speedy!=0:
                         senh.setbox(f"y {speedy:.3f}",  senh.speedy)
+                    if substract_background:
+                        senh.setbox("-BCKG",  senh.SUBBG )
 
 
                     # ----------------expo gain gamma
