@@ -25,6 +25,7 @@ class Stream_Enhancer:
 
     DISP=(0,4) # gree
     MODE=(0,3) # red
+    SUBBG = (0,5) # substract background
 
     # lap   = (1,0)
     # expo  = (3,0)
@@ -86,6 +87,7 @@ class Stream_Enhancer:
         if (row,col) == self.TIME: return (200,0,0)
         if (row,col) == self.MODE: return (0,0,255)
         if (row,col) == self.DISP: return (0,205,0)
+        if (row,col) == self.SUBBG: return (90,50,200)
 
         if (row,col) == self.lap: return (200,100,200) #
         if row==1 and col==1: return (150,150,150) #
