@@ -34,6 +34,7 @@ import getpass
 import sys
 
 from flashcam.stream_enhancer import Stream_Enhancer
+import webbrowser
 
 @contextmanager
 def timeout(time):
@@ -128,6 +129,7 @@ def get_stream3( videodev, passfile ):
 def display3(videodev, save = False,
          passfile="~/.pycamfw_userpass"):
     stream = None
+    stream_length = 1024*50
     if stream is None: # LOGIN
         stream, u, p = get_stream3(videodev, passfile)
 
@@ -147,7 +149,7 @@ def display3(videodev, save = False,
 
         try:
             # THIS CAN TIMEOUT ######################################### i catch
-            bytex += stream.read(1024*40) # i multiply by 10 as later...
+            bytex += stream.read(stream_length) # i multiply by 10 as later...
             got_data = True
         except:
             print("X... exception - timout in 1.st stream.read, ")
@@ -274,9 +276,12 @@ def display2(videodev, save = False,
 
         return stream, u, p
 
+
+    # ********************************************************** main loop
     io_none = 0 # to reset stream
     sfilename = ""  # move up to limi # of AVI files.... tst?
     sfilenamea = ""
+    stream_length = 1024*50
     if save:
         sfilenamea,saviout = setupsave()
     while True: #==================== MAIN LOOP =================
@@ -333,7 +338,7 @@ def display2(videodev, save = False,
                 try:
                     # THIS CAN TIMEOUT #########################################
                     print("D... try ...", end="")
-                    bytex += stream.read(1024*50) #  must be long enough?
+                    bytex += stream.read(stream_length) #  must be long enough?
                 except:
                     print("X... exception - timout in 1.st stream.read, ")
                     #bytex+=b"\x00\x00\x00"
@@ -351,6 +356,7 @@ def display2(videodev, save = False,
                         frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
                         ret_val= 1
                         io_none = 0
+                        stream_length = b+2-a
                     else:
                         ret_val = 0
                         # print("D...                ok frame http",oi,len(bytex) )
@@ -413,7 +419,7 @@ def display2(videodev, save = False,
                         while ret_val == 0:
                             for i8 in range(1): # I decimate and remove delay
                                 #print("1-", flush=True,end="")
-                                bytex += stream.read(1024*50)
+                                bytex += stream.read(stream_length)
                                 a = bytex.find(b'\xff\xd8') #frame starting
                                 b = bytex.find(b'\xff\xd9') #frame ending
                                 if a != -1 and b != -1:
@@ -423,6 +429,8 @@ def display2(videodev, save = False,
                                         FPS+=1
                                     bytex = bytex[b+2:]
                                     frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
+                                    stream_length = b+2-a
+
                                     ret_val=1
                                     print("   {:4.1f}Mb/s {}fps {} {}".format(
                                         # len(bytex)/1024,
@@ -489,6 +497,11 @@ def display2(videodev, save = False,
                 # time.sleep(0.2)
                 key = cv2.waitKey(1)
 
+                if (not frame is None) and (rpi_name!="") and (key == ord('w')):
+                    print("W PRESSED! - openning web browser")
+                    webbrowser.open( videodev.replace("/video","" ) ) # BRUTAL
+
+
                 if (not frame is None) and (rpi_name!="") and (key == ord('a')):
                     print("A PRESSED! - saving AVI")
                     save = True
