@@ -169,28 +169,46 @@ setInterval(doDate, 200);
       <button style="width:20%" name="down2" value="DOWN2">down2</button>
   </div>
 <hr>
-  <div class="btn-group" style="width:100%">
-      <button style="width:8%" name="savebg" value="SAVEBG">saveBG</button>
-      <button style="width:8%" name="subbg" value="SUBBG">subBG</button>
- <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
+
+<table>
+<tr>
+<td>
+   <button style="width:100%" name="savebg" value="SAVEBG">saveBG</button>
+</td>
+ <td align="left" rowspan="2">
+    <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
+ </td>
+ <td>
+   <button style="width:100%" name="timelaps" value="TIMELAPS">LAPS</button> <input type = "text" name = "timelaps_input" size="5"  placeholder="0" />
+ </td>
+</tr>
+<tr>
+ <td>
+    <button style="width:100%" name="subbg" value="SUBBG">subBG</button>
+ </td>
+</tr>
+</table>
+
 <hr>
       <button style="width:4%" name="speedx" value="SPEEDX">dX</button>
-    <input type = "text" name = "inputx"  size="6" />
+    <input type = "text" name = "inputx"  size="5" />
       <button style="width:4%" name="speedy" value="SPEEDY">dY</button>
-    <input type = "text" name = "inputy" size="6" />
+    <input type = "text" name = "inputy" size="5" />
 
-      <button style="width:8%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
-      <button style="width:8%" name="zero_translate" value="ZERO_TRANSLATE">zero</button>
-<br>
-      <button style="width:8%" name="accum" value="ACCUM">Accum</button>
+      <button style="width:7%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
+      <button style="width:7%" name="zero_translate" value="ZERO_TRANSLATE">zero</button>
+      <button style="width:7%" name="accum" value="ACCUM">Accum</button>
       &nbsp; &nbsp;&nbsp; <input type = "text" name = "accumtxt" size="6" />
 <hr>
-      <button style="width:8%" name="gamma2" value="GAMMA2">gm x2</button>
-      <button style="width:8%" name="gamma05" value="GAMMA05">gm /2</button>
-      <button style="width:8%" name="gamma" value="GAMMA">gm def</button>
-      <button style="width:8%" name="gain2" value="GAIN2">ga x2</button>
-      <button style="width:8%" name="gain05" value="GAIN05">ga /2</button>
-      <button style="width:8%" name="gain" value="GAIN">ga def</button>
+      <button style="width:6%" name="gamma2" value="GAMMA2">gm x2</button>
+      <button style="width:6%" name="gamma05" value="GAMMA05">gm /2</button>
+      <button style="width:6%" name="gamma" value="GAMMA">gm def</button>
+      <button style="width:6%" name="gain2" value="GAIN2">ga x2</button>
+      <button style="width:6%" name="gain05" value="GAIN05">ga /2</button>
+      <button style="width:6%" name="gain" value="GAIN">ga def</button>
+      <button style="width:6%" name="expo05" value="EXPO05">ex /2</button>
+      <button style="width:6%" name="expo2" value="EXPO2">ex x2</button>
+      <button style="width:6%" name="expo" value="EXPO">ex def</button>
 
   </div>
 
@@ -237,6 +255,8 @@ def cross():
 
     print(request.method)
     if request.method == 'POST':
+
+        # ------------------------------------------- EXECUTE EXECUTION part for real_camera
         if request.form.get('savebg') == 'SAVEBG':
             print("i... saving BG" )
             save_bg = True
@@ -297,11 +317,27 @@ def cross():
         if request.form.get('gain') == 'GAIN':
             mmwrite(f"gain_setdef True" )
 
+        if request.form.get('expo2') == 'EXPO2':
+            mmwrite(f"expo_multiply True" )
+        if request.form.get('expo05') == 'EXPO05':
+            mmwrite(f"expo_divide True" )
+        if request.form.get('expo') == 'EXPO':
+            mmwrite(f"expo_setdef True" )
+
+        if request.form.get('timelaps') == 'TIMELAPS':
+            timelaps = request.form.get('timelaps_input')
+            try:
+                speedy = int(timelaps)
+                print("i...  Y",  timelaps)
+                mmwrite(f"timelaps {timelaps}" )
+            except:
+                print("D... unknown value timelaps")
 
 
 
 
-        # --------------------------------- Cross controls
+
+        # ---------------------------------------------- Cross controls
         if cross_on:
             if request.form.get('left2') == 'LEFT2':
                 print("left2")
